==> cloud-5.0.0-rc2.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/form/aws_cloud/vpc/vpc.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const AWS_CLOUD_VPC_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'vpc',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'VPC',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { type: 'default', labelName: 'IPv4 CIDR block', name: 'cidr_block', defaultValue: '', required: true },
          { type: 'select-local', labelName: 'IPv6 CIDR block', name: 'amazon_provided_ipv6_cidr_block', defaultValue: '0', value: [
            { name: '0', labelName: 'No IPv6 CIDR Block' },
            { name: '1', labelName: 'Amazon provided IPv6 CIDR block' },
          ] },
          { type: 'select-local', labelName: 'Tenancy', name: 'instance_tenancy', defaultValue: 'default', value: [
            { name: 'default', labelName: 'Default' },
            { name: 'dedicated', labelName: 'Dedicated' },
          ] },
          { type: 'boolean', labelName: 'Flow log', name: 'flow_log', defaultValue: false }
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'vpc',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'VPC',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { type: 'default', labelName: 'VPC ID', name: 'vpc_id', defaultValue: '', readOnly: true },
          { type: 'datetime', labelName: 'Created', name: 'created', defaultValue: 0, readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Flow logs',
        keyValueRecords: [
          { type: 'boolean', labelName: 'Flow log', name: 'flow_log', defaultValue: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Tags',
        keyValueRecords: [
          { type: 'key-value', labelName: 'Tags', name: 'tags', defaultValue: [] },
        ]
      },
      {
        type: 'panel',
        panelName: 'CIDR Blocks',
        keyValueRecords: [
          { type: 'item-array', labelName: 'IPv4 CIDR', name: 'cidr_blocks', defaultValue: [], info: [
            { labelName: 'CIDR', name: 'cidr', },
            { labelName: 'State', name: 'state', readOnly: true },
            { labelName: 'Status reason', name: 'status_message', readOnly: true },
            { labelName: 'Association ID', name: 'association_id', readOnly: true },
          ] },
          { type: 'item-array', labelName: 'IPv6 CIDR', name: 'ipv6_cidr_blocks', defaultValue: [], info: [
            { labelName: 'CIDR', name: 'cidr', },
            { labelName: 'State', name: 'state', readOnly: true },
            { labelName: 'Status reason', name: 'status_message', readOnly: true },
            { labelName: 'Association ID', name: 'association_id', readOnly: true },
          ] },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'vpc',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{entityName}} {{name}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
]

export default AWS_CLOUD_VPC_TEMPLATE;

==> cloud-5.1.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/form/aws_cloud/vpc/vpc.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const AWS_CLOUD_VPC_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'vpc',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'VPC',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { type: 'default', labelName: 'IPv4 CIDR block', name: 'cidr_block', defaultValue: '', required: true },
          { type: 'select-local', labelName: 'IPv6 CIDR block', name: 'amazon_provided_ipv6_cidr_block', defaultValue: '0', value: [
            { name: '0', labelName: 'No IPv6 CIDR Block' },
            { name: '1', labelName: 'Amazon provided IPv6 CIDR block' },
          ] },
          { type: 'select-local', labelName: 'Tenancy', name: 'instance_tenancy', defaultValue: 'default', value: [
            { name: 'default', labelName: 'Default' },
            { name: 'dedicated', labelName: 'Dedicated' },
          ] },
          { type: 'boolean', labelName: 'Flow log', name: 'flow_log', defaultValue: false }
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'vpc',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'VPC',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { type: 'default', labelName: 'VPC ID', name: 'vpc_id', defaultValue: '', readOnly: true },
          { type: 'datetime', labelName: 'Created', name: 'created', defaultValue: 0, readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Flow logs',
        keyValueRecords: [
          { type: 'boolean', labelName: 'Flow log', name: 'flow_log', defaultValue: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Tags',
        keyValueRecords: [
          { type: 'key-value', labelName: 'Tags', name: 'tags', defaultValue: [] },
        ]
      },
      {
        type: 'panel',
        panelName: 'CIDR Blocks',
        keyValueRecords: [
          { type: 'item-array', labelName: 'IPv4 CIDR', name: 'cidr_blocks', defaultValue: [], info: [
            { labelName: 'CIDR', name: 'cidr', type: 'default' },
            { labelName: 'State', name: 'state', type: 'default', readOnly: true },
            { labelName: 'Status reason', name: 'status_message', type: 'default', readOnly: true },
            { labelName: 'Association ID', name: 'association_id', type: 'default', readOnly: true },
          ] },
          { type: 'item-array', labelName: 'IPv6 CIDR', name: 'ipv6_cidr_blocks', defaultValue: [], info: [
            { labelName: 'CIDR', name: 'cidr', type: 'default' },
            { labelName: 'State', name: 'state', type: 'default', readOnly: true },
            { labelName: 'Status reason', name: 'status_message', type: 'default', readOnly: true },
            { labelName: 'Association ID', name: 'association_id', type: 'default', readOnly: true },
          ] },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'vpc',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{entityName}} {{name}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
]

export default AWS_CLOUD_VPC_TEMPLATE;
